@@ -169,8 +169,12 @@ class Responder:
         if service is None:
             return
 
+        txt_record = self._txt_record_for(service)
+        if txt_record is None:
+            return
+
         self._dprint("Responding to DNS TXT question for {}".format(query))
-        srv_answers = [self._txt_record_for(service)]
+        srv_answers = [txt_record]
         self._send_response(srv_answers)
 
     def _get_service_of(self, query: str) -> "Optional[str]":
@@ -186,7 +190,7 @@ class Responder:
     def _ptr_record_for(self, query: str) -> DNSRecord:
         ptr_target = ".".join((self.host, query))
         # For some reason the PTR is shortened and the last two bytes are removed
-        ptr_target_bytes = name_to_bytes(ptr_target)[:-2] 
+        ptr_target_bytes = name_to_bytes(ptr_target)
         return DNSRecord(query, TYPE_PTR, CLASS_IN, DEFAULT_TTL, ptr_target_bytes)
 
     def _srv_record_for(self, query: str) -> "Optional[DNSRecord]":
